@@ -4,7 +4,7 @@
  * GChemPaint library
  * mechanism-step.h 
  *
- * Copyright (C) 2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2009-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -36,6 +36,15 @@ class MechanismStep: public gcu::Object
 public:
 	MechanismStep (gcu::TypeId type = MechanismStepType);
 	virtual ~MechanismStep ();
+
+	double GetYAlign ();
+	bool OnSignal (gcu::SignalId Signal, gcu::Object *Child);
+	bool Load (xmlNodePtr node);
+
+	std::string Name ();
+
+private:
+	bool m_bLoading;
 };
 
 }	//	namespace gcp
