@@ -4,7 +4,7 @@
  * GChemPaint library
  * theme.h
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,17 +27,6 @@
 
 #include <gcu/macros.h>
 #include <gcu/object.h>
-#include <glib/gtypes.h>
-#include <pango/pango.h>
-#ifdef HAVE_GO_CONF_SYNC
-#   ifdef GOFFICE_HAS_GLOBAL_HEADER
-#      include <goffice/goffice.h>
-#   else
-#	   include <goffice/app/go-conf.h>
-#   endif
-#else
-#   include <gconf/gconf-client.h>
-#endif
 #include <libxml/tree.h>
 #include <list>
 #include <map>
@@ -309,7 +298,6 @@ The destructor.
 @return the list of all theme names currently in use.
 */
 	std::list <std::string> const &GetThemesNames ();
-#ifdef HAVE_GO_CONF_SYNC
 /*!
 @param node the GOConfNode for which a key value changed.
 @param name the key whose value changed.
@@ -318,17 +306,6 @@ Called by the framework when the value associated with \a name changed in the
 settings.
 */
 	void OnConfigChanged (GOConfNode *node, gchar const *name);
-#else
-/*!
-@param client the GConfClient which a key value changed.
-@param cnxn_id the notification id.
-@param entry the entry which changed.
-
-Called by the framework when the value associated with \a entry changed in the
-settings.
-*/
-	void OnConfigChanged (GConfClient *client,  guint cnxn_id, GConfEntry *entry);
-#endif
 /*!
 @param theme a theme to duplicate.
 
@@ -382,11 +359,7 @@ private:
 private:
 	std::map <std::string, Theme*> m_Themes;
 	std::list <std::string> m_Names;
-#ifdef HAVE_GO_CONF_SYNC
 	GOConfNode *m_ConfNode;
-#else
-	GConfClient *m_ConfClient;
-#endif
 	guint m_NotificationId;
 	Theme *m_DefaultTheme;
 };
