@@ -71,8 +71,10 @@ gchar const *LatticeName[] = {
 };
 
 CrystalDoc::CrystalDoc (Application *App): GLDocument (App),
-	m_SpaceGroup (NULL)
+	m_SpaceGroup (NULL), m_AutoSpaceGroup (false)
 {
+	m_xmin = m_ymin = m_zmin = 0;
+	m_xmax = m_ymax = m_zmax = 1;
 }
 
 
@@ -134,6 +136,8 @@ void CrystalDoc::Init()
 	m_a = m_b = m_c = 100;
 	m_alpha = m_beta = m_gamma = 90;
 	m_lattice = cubic;
+	m_SpaceGroup = SpaceGroup::GetSpaceGroup (195);
+	m_AutoSpaceGroup = false;
 	m_xmin = m_ymin = m_zmin = 0;
 	m_xmax = m_ymax = m_zmax = 1;
 	m_bFixedSize = false;
@@ -760,7 +764,7 @@ xmlDocPtr CrystalDoc::BuildXMLTree () const
 	}
 }
 
-void CrystalDoc::Loaded ()
+bool CrystalDoc::Loaded () throw (LoaderError)
 {
 	if (m_NameCommon.length () > 0)
 		SetTitle (m_NameCommon);
@@ -825,6 +829,7 @@ void CrystalDoc::Loaded ()
 	}
 
 	Update ();
+	return false;	// no pending reference updated
 }
 
 bool CrystalDoc::SetProperty (unsigned property, char const *value)
@@ -962,7 +967,7 @@ SpaceGroup const *CrystalDoc::FindSpaceGroup ()
 {
 	if (!AtomDef.size ())
 		return NULL;
-	if (m_SpaceGroup)
+	if (m_SpaceGroup && !m_AutoSpaceGroup)
 		return (m_SpaceGroup);
 	unsigned start, end, id;
 	switch (m_lattice) {
@@ -1097,6 +1102,8 @@ end_loop:;
 	for (i = atoms.begin (); i != iend; i++)
 		delete *i;
 	// now, search for duplicates in AtomDef
+	if (!res)
+		return NULL;
 	set <CrystalAtom *> dups;
 	iend = AtomDef.end ();
 	for (i = AtomDef.begin (); i != iend; i++) {
