@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * matrix.h 
  *
- * Copyright (C) 2000-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,12 +25,12 @@
 #ifndef GCU_MATRIX_H
 #define GCU_MATRIX_H
 
-#include <openbabel/math/vector3.h>
-
 /*!\file*/
 namespace gcu
 {
 
+class Vector;
+
 /*!\enum MatrixType
 This enumeration is used to determine the type a Matrix.
 Possible values are:
@@ -51,10 +51,23 @@ class Matrix
 public:
 
 /*!
-Default constructor. Members are not initialized. This constructor is rarely used.
+Default constructor. Initialized to unit matrix.
 */
 	Matrix ();
 /*!
+@param d a number.
+Constructs a scalar matrix. Initializes diagonal elements to \a d and other elements to 0.
+*/
+	Matrix (double d);
+	Matrix (double d[3][3]);
+/*!
+@param m a matrix.
+Copy contructor.
+*/
+	Matrix (Matrix const &m);
+
+	Matrix (Vector const &v1, Vector const &v2, Vector const &v3, bool as_rows = true);
+/*!
 The destructor of Matrix.
 */
 	virtual ~Matrix ();
@@ -120,7 +133,10 @@ Initially, dx, dy and dz are the components of the vector to transform (multiply
 after execution of this method, dx, dy and dz are the components of the transformed vector. So initial values are lost.
 */
 	void Transform (double &dx, double &dy , double &dz) const;
-	OpenBabel::vector3 operator* (OpenBabel::vector3 const &v) const;
+	Vector operator* (Vector const &v) const;
+	Vector glmult (Vector const &v) const;
+	double &operator() (unsigned i, unsigned j) {return x[i][j];}
+	double operator() (unsigned i, unsigned j) const {return x[i][j];}
 	
 private:
 	double x[3][3];
