@@ -26,16 +26,22 @@
 #include "selectiontool.h"
 #include "group.h"
 #include "groupdlg.h"
+#include <gcp/application.h>
+#include <gcp/document.h>
 #include <gcp/molecule.h>
 #include <gcp/settings.h>
-#include <gcp/document.h>
-#include <gcp/application.h>
 #include <gcp/theme.h>
+#include <gcp/view.h>
 #include <gcp/window.h>
+#include <gccv/canvas.h>
+#include <gccv/group.h>
+#include <gccv/rectangle.h>
+#include <gccv/structs.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <stdexcept>
 
+using namespace gccv;
 using namespace gcu;
 using namespace std;
 
@@ -57,7 +63,7 @@ static void on_rotate (GtkWidget *btn, gcp::Application* App)
 		tool->Rotate (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (btn)));
 }
 
-static void on_merge (GtkWidget *btn, gcp::Application* App)
+static void on_merge (G_GNUC_UNUSED GtkWidget *btn, gcp::Application* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->Merge ();
@@ -101,7 +107,7 @@ bool gcpSelectionTool::OnClicked ()
 	}
 	if (m_bRotate) {
 		// Calculate center of selection
-		ArtDRect rect;
+		gccv::Rect rect;
 		m_pData->GetSelectionBounds (rect);
 		m_cx = (rect.x0 + rect.x1) / 2.;
 		m_cy = (rect.y0 + rect.y1) / 2.;
@@ -124,7 +130,7 @@ bool gcpSelectionTool::OnClicked ()
 
 void gcpSelectionTool::OnDrag ()
 {
-	double dx = m_x - m_x1, dy = m_y - m_y1, x1, y1, x2, y2;
+	double dx = m_x - m_x1, dy = m_y - m_y1;
 	m_x1 = m_x;
 	m_y1 = m_y;
 	if (m_pObject) {
@@ -158,22 +164,14 @@ void gcpSelectionTool::OnDrag ()
 		} else
 			m_pData->MoveSelectedItems (dx, dy);
 	} else {
-		if (m_pItem) {
-			gnome_canvas_item_get_bounds (m_pItem, &x1, &y1, &x2, &y2);
-			g_object_set (G_OBJECT (m_pItem), "x2", m_x, "y2", m_y, NULL);
-			gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
+		if (m_Item) {
+			reinterpret_cast <Rectangle *> (m_Item)->SetPosition (m_x0, m_y0, m_x - m_x0, m_y - m_y0);
 		} else {
+			m_Item = new Rectangle (m_pView->GetCanvas (), m_x0, m_y0, m_x - m_x0, m_y - m_y0);
 			gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
-			m_pItem = gnome_canvas_item_new (
-									m_pData->Group,
-									gnome_canvas_rect_get_type (),
-									"x1", m_x0,
-									"y1", m_y0,
-									"x2", m_x,
-									"y2", m_y,
-									"outline_color", gcp::SelectColor,
-									"width_units", pTheme->GetBondWidth (),
-									NULL);
+			static_cast <LineItem *> (m_Item)->SetLineColor (gcp::SelectColor);
+			static_cast <LineItem *> (m_Item)->SetLineWidth (pTheme->GetBondWidth ());
+			static_cast <FillItem *> (m_Item)->SetFillColor (0);
 		}
 	}
 }
@@ -208,23 +206,28 @@ void gcpSelectionTool::OnRelease ()
 		else
 			m_y1 = m_y;
 		double x0, y0, x1, y1;
-		std::map<Object const *, GnomeCanvasGroup*>::iterator j, jend = m_pData->Items.end ();
-		for (j = m_pData->Items.begin (); j != jend; j++) {
-			if (!m_pData->IsSelected ((*j).first)) {
-				GnomeCanvasItem *item = GNOME_CANVAS_ITEM ((*j).second);
-				if (!item)
-					continue;
-				gnome_canvas_item_get_bounds (item, &x0, &y0,&x1, &y1);
-				if ((x0 < m_x1) && (y0 < m_y1) && (x1 > m_x0) && (y1 > m_y0)) {
-					m_pObject = (*j).first->GetGroup ();	//GetMolecule();
-					if (m_pObject) {
-						if (!m_pData->IsSelected (m_pObject))
-							m_pData->SetSelected (m_pObject);
-					}
-					else
-						m_pData->SetSelected (const_cast <Object *> ((*j).first));
+		if (m_Item) {
+			delete m_Item;
+			m_Item = NULL;
+		}
+		gccv::Group *group = m_pView->GetCanvas ()->GetRoot ();
+		// all client top items are implemented as a child of the root
+		list<Item *>::iterator it;
+		Item *item = group->GetFirstChild (it);
+		Object *object;
+		while (item) {
+			item->GetBounds (x0, y0, x1, y1);
+			if ((x0 < m_x1) && (y0 < m_y1) && (x1 > m_x0) && (y1 > m_y0)) {
+				object = dynamic_cast <Object *> (item->GetClient ());
+				m_pObject = object->GetGroup ();
+				if (m_pObject) {
+					if (!m_pData->IsSelected (m_pObject))
+						m_pData->SetSelected (m_pObject);
 				}
+				else
+					m_pData->SetSelected (object);
 			}
+			item = group->GetNextChild (it);
 		}
 	}
 	AddSelection (m_pData);
@@ -289,7 +292,7 @@ void gcpSelectionTool::OnFlip (bool horizontal)
 	}
 	if (!m_pData->SelectedObjects.size ())
 		return;
-	ArtDRect rect;
+	gccv::Rect rect;
 	m_pData->GetSelectionBounds (rect);
 	m_cx = (rect.x0 + rect.x1) / 2.;
 	m_cy = (rect.y0 + rect.y1) / 2.;
@@ -375,13 +378,14 @@ void gcpSelectionTool::CreateGroup ()
 			return;
 		}
 		m_pView->Update (pObj);
+		m_pView->EnsureSize ();
 		m_pData->UnselectAll ();
 		m_pData->SetSelected (pObj);
 		AddSelection (m_pData);
 		m_pOp->AddObject (pObj, 1);
 		pDoc->FinishOperation ();
 	}
-	catch (invalid_argument &e) {
+	catch (invalid_argument& e) {
 			pDoc->AbortOperation ();
 			delete pObj;
 			GtkWidget* message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0,
@@ -484,7 +488,6 @@ GtkWidget *gcpSelectionTool::GetPropertyPage ()
 	w = gtk_ui_manager_get_widget (m_UIManager, "/Selection");
 	gtk_toolbar_set_style (GTK_TOOLBAR (w), GTK_TOOLBAR_ICONS);
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (w), false);
-	gtk_toolbar_set_tooltips (GTK_TOOLBAR (w), true);
 	gtk_box_pack_start (GTK_BOX (box), w, false, false, 0);
 	gtk_widget_show_all (box);
 	m_MergeBtn = gtk_ui_manager_get_widget (m_UIManager, "/Selection/Merge");
